@@ -36,7 +36,6 @@
 #define RAK_ALGORITHM_H
 
 #include <algorithm>
-#include <functional>
 #include <limits>
 
 namespace rak {
@@ -113,7 +112,7 @@ advance_backward(_InputIter __first, _InputIter __last, _Distance __distance) {
 }
 
 template <typename _Value>
-struct compare_base : public std::function<bool(_Value, _Value)> {
+struct compare_base {
   bool operator () (const _Value& complete, const _Value& base) const {
     return !complete.compare(0, base.size(), base);
   }
