@@ -6,9 +6,7 @@
 #include <netdb.h>
 #include <unistd.h>
 #include <rak/file_stat.h>
-#include <rak/error_number.h>
 #include <rak/path.h>
-#include <rak/socket_address.h>
 #include <rak/string_manip.h>
 #include <rak/regex.h>
 #include <torrent/rate.h>
@@ -27,9 +25,9 @@
 #include <torrent/utils/option_strings.h>
 
 #include "core/download.h"
-#include "core/download_store.h"
 #include "core/manager.h"
 #include "rpc/parse.h"
+#include "session/session_manager.h"
 
 #include "globals.h"
 #include "control.h"
@@ -104,22 +102,19 @@ apply_d_change_link(core::Download* download, const torrent::Object::list_type&
 
   switch (changeType) {
   case 0:
-    if (symlink(target.c_str(), link.c_str()) == -1){
-      lt_log_print(torrent::LOG_TORRENT_WARN, "create_link failed: %s",
-                   rak::error_number::current().c_str());
-    }
+    if (symlink(target.c_str(), link.c_str()) == -1)
+      lt_log_print(torrent::LOG_TORRENT_WARN, "create_link failed: %s", std::strerror(errno));
+
     break;
 
   case 1:
   {
     rak::file_stat fileStat;
-    rak::error_number::clear_global();
+    errno = 0;
+
+    if (!fileStat.update_link(link) || !fileStat.is_link() || unlink(link.c_str()) == -1)
+      lt_log_print(torrent::LOG_TORRENT_WARN, "delete_link failed: %s", std::strerror(errno));
 
-    if (!fileStat.update_link(link) || !fileStat.is_link() ||
-        unlink(link.c_str()) == -1){
-      lt_log_print(torrent::LOG_TORRENT_WARN, "delete_link failed: %s",
-          rak::error_number::current().c_str());
-    }
     break;
   }
   default:
@@ -137,7 +132,7 @@ apply_d_delete_tied(core::Download* download) {
     return torrent::Object();
 
   if (::unlink(rak::path_expand(tie).c_str()) == -1)
-    control->core()->push_log_std("Could not unlink tied file: " + std::string(rak::error_number::current().c_str()));
+    control->core()->push_log_std("Could not unlink tied file: " + std::string(std::strerror(errno)));
 
   rpc::call_command("d.tied_to_file.set", std::string(), rpc::make_target(download));
   return torrent::Object();
@@ -307,7 +302,7 @@ apply_d_add_peer(core::Download* download, const std::string& arg) {
   if (port < 1 || port > 65535)
     throw torrent::input_error("Invalid port number.");
 
-  assert(std::this_thread::get_id() == torrent::main_thread::thread()->thread_id());
+  assert(std::this_thread::get_id() == torrent::main_thread::thread_id());
 
   // Currently discarding SOCK_STREAM.
   torrent::this_thread::resolver()->resolve_preferred(NULL, host, AF_UNSPEC, AF_INET, [download, port](torrent::c_sa_shared_ptr sa, int err) {
@@ -500,6 +495,19 @@ download_get_variable(core::Download* download, const char* first_key, const cha
   return download->bencode()->get_key(first_key).get_key(second_key);
 }
 
+torrent::Object
+download_get_value_or_zero(core::Download* download, const char* first_key, const char* second_key = NULL) {
+  auto object = download_get_variable(download, first_key, second_key);
+
+  if (object.is_empty())
+    return int64_t(0);
+
+  if (!object.is_value())
+    throw torrent::bencode_error("Download variable is not a value.");
+
+  return object;
+}
+
 torrent::Object
 download_set_variable(core::Download* download, const torrent::Object& rawArgs, const char* first_key, const char* second_key = NULL) {
   if (second_key == NULL)
@@ -544,16 +552,13 @@ download_set_variable_string(core::Download* download, const torrent::Object::st
 //
 
 torrent::Object
-d_list_push_back_string(core::Download* download, const torrent::Object& rawArgs, const char* first_key, const char* second_key) {
-  auto& arg = rawArgs.as_string();
+d_list_push_back_string(core::Download* download, const std::string& arg, const char* first_key, const char* second_key) {
   download_get_variable(download, first_key, second_key).as_list().push_back(arg);
-
   return torrent::Object();
 }
 
 torrent::Object
-d_list_push_back_unique_string(core::Download* download, const torrent::Object& rawArgs, const char* first_key, const char* second_key) {
-  auto& arg = rawArgs.as_string();
+d_list_push_back_unique_string(core::Download* download, const std::string& arg, const char* first_key, const char* second_key) {
   torrent::Object::list_type& list = download_get_variable(download, first_key, second_key).as_list();
 
   if (std::none_of(list.begin(), list.end(), [arg](const torrent::Object& obj) { return torrent::object_equal(obj, arg); }))
@@ -608,12 +613,16 @@ d_list_remove(core::Download* download, const torrent::Object& rawArgs, const ch
 
 #define CMD2_DL_TIMESTAMP(key, first_key, second_key)                   \
   CMD2_DL(key, std::bind(&download_get_variable, std::placeholders::_1, first_key, second_key)); \
-  CMD2_DL_VALUE_P(key ".set", std::bind(&download_set_variable_value, \
-                                             std::placeholders::_1, std::placeholders::_2, \
-                                             first_key, second_key)); \
+  CMD2_DL_VALUE_P(key ".set", std::bind(&download_set_variable_value,   \
+                                        std::placeholders::_1, std::placeholders::_2, \
+                                        first_key, second_key));        \
   CMD2_DL_VALUE_P(key ".set_if_z", std::bind(&download_set_variable_value_ifz, \
                                              std::placeholders::_1, std::placeholders::_2, \
                                              first_key, second_key));   \
+  CMD2_DL(key ".or_zero", [](core::Download* download, auto) {          \
+      return download_get_value_or_zero(download, first_key, second_key); }); \
+  CMD2_DL_VALUE(key ".elapsed", [](core::Download* download, auto value) { \
+      return download_get_value_or_zero(download, first_key, second_key).as_value() > value; });
 
 #define CMD2_DL_VAR_STRING(key, first_key, second_key)                   \
   CMD2_DL(key, std::bind(&download_get_variable, std::placeholders::_1, first_key, second_key)); \
@@ -691,8 +700,8 @@ initialize_command_download() {
   CMD2_DL_V       ("d.erase",      std::bind(&core::DownloadList::erase_ptr, control->core()->download_list(), std::placeholders::_1));
   CMD2_DL_V       ("d.check_hash", std::bind(&core::DownloadList::check_hash, control->core()->download_list(), std::placeholders::_1));
 
-  CMD2_DL         ("d.save_resume",       std::bind(&core::DownloadStore::save_resume, control->core()->download_store(), std::placeholders::_1));
-  CMD2_DL         ("d.save_full_session", std::bind(&core::DownloadStore::save_full, control->core()->download_store(), std::placeholders::_1));
+  CMD2_DL_V       ("d.save_resume",       [](core::Download* download, auto) { session_thread::manager()->save_resume_download(download); });
+  CMD2_DL_V       ("d.save_full_session", [](core::Download* download, auto) { session_thread::manager()->save_full_download(download); });
 
   CMD2_DL_V       ("d.update_priorities", CMD2_ON_DL(update_priorities));
 
@@ -774,8 +783,8 @@ initialize_command_download() {
   CMD2_DL         ("d.views",                  std::bind(&download_get_variable, std::placeholders::_1, "rtorrent", "views"));
   CMD2_DL         ("d.views.has",              std::bind(&d_list_has, std::placeholders::_1, std::placeholders::_2, "rtorrent", "views"));
   CMD2_DL         ("d.views.remove",           std::bind(&d_list_remove, std::placeholders::_1, std::placeholders::_2, "rtorrent", "views"));
-  CMD2_DL         ("d.views.push_back",        std::bind(&d_list_push_back_string, std::placeholders::_1, std::placeholders::_2, "rtorrent", "views"));
-  CMD2_DL         ("d.views.push_back_unique", std::bind(&d_list_push_back_unique_string, std::placeholders::_1, std::placeholders::_2, "rtorrent", "views"));
+  CMD2_DL_STRING  ("d.views.push_back",        std::bind(&d_list_push_back_string, std::placeholders::_1, std::placeholders::_2, "rtorrent", "views"));
+  CMD2_DL_STRING  ("d.views.push_back_unique", std::bind(&d_list_push_back_unique_string, std::placeholders::_1, std::placeholders::_2, "rtorrent", "views"));
 
   // This command really needs to be improved, so we have proper
   // logging support.
