@@ -1,47 +1,14 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <sundell.software@gmail.com>
-
-
 #include "config.h"
 
 #include <cstdio>
-#include <rak/address_info.h>
 #include <torrent/throttle.h>
 #include <torrent/rate.h>
 #include <torrent/download/resource_manager.h>
+#include <torrent/net/socket_address.h>
 
 #include "core/manager.h"
 #include "ui/root.h"
+#include "rak/address_info.h"
 #include "rpc/parse.h"
 #include "rpc/parse_commands.h"
 
@@ -57,13 +24,16 @@ parse_address_range(const torrent::Object::list_type& args, torrent::Object::lis
   rak::address_info* ai;
 
   ret = std::sscanf(itr->as_string().c_str(), "%1023[^/]/%d%c", host, &prefixWidth, &dummy);
+
   if (ret < 1 || rak::address_info::get_address_info(host, PF_INET, SOCK_STREAM, &ai) != 0)
     throw torrent::input_error("Could not resolve host.");
 
   uint32_t begin, end;
-  rak::socket_address sa;
-  sa.copy(*ai->address(), ai->length());
-  begin = end = sa.sa_inet()->address_h();
+  auto sa = torrent::sa_copy(ai->c_addrinfo()->ai_addr);
+  auto sa_addr = htonl(reinterpret_cast<sockaddr_in*>(sa.get())->sin_addr.s_addr);
+
+  begin = end = sa_addr;
+
   rak::address_info::free_address_info(ai);
 
   if (ret == 2) {
@@ -71,18 +41,21 @@ parse_address_range(const torrent::Object::list_type& args, torrent::Object::lis
       throw torrent::input_error("Cannot specify both network and range end.");
 
     uint32_t netmask = std::numeric_limits<uint32_t>::max() << (32 - prefixWidth);
-    if (prefixWidth >= 32 || sa.sa_inet()->address_h() & ~netmask)
+
+    if (prefixWidth >= 32 || sa_addr & ~netmask)
       throw torrent::input_error("Invalid address/prefix.");
 
-    end = sa.sa_inet()->address_h() | ~netmask;
+    end = sa_addr | ~netmask;
 
   } else if (++itr != args.end()) {
     if (rak::address_info::get_address_info(itr->as_string().c_str(), PF_INET, SOCK_STREAM, &ai) != 0)
       throw torrent::input_error("Could not resolve host.");
 
-    sa.copy(*ai->address(), ai->length());
+    sa = torrent::sa_copy(ai->c_addrinfo()->ai_addr);
+    sa_addr = htonl(reinterpret_cast<sockaddr_in*>(sa.get())->sin_addr.s_addr);
+
     rak::address_info::free_address_info(ai);
-    end = sa.sa_inet()->address_h();
+    end = sa_addr;
   }
 
   // convert to [begin, end) making sure the end doesn't overflow
@@ -194,10 +167,10 @@ initialize_command_throttle() {
   CMD2_VAR_VALUE   ("throttle.max_downloads.div._val",    1);
   CMD2_VAR_VALUE   ("throttle.max_downloads.global._val", 0);
 
-  CMD2_REDIRECT_GENERIC("throttle.max_uploads.div",      "throttle.max_uploads.div._val");
-  CMD2_REDIRECT_GENERIC("throttle.max_uploads.global",   "throttle.max_uploads.global._val");
-  CMD2_REDIRECT_GENERIC("throttle.max_downloads.div",    "throttle.max_downloads.div._val");
-  CMD2_REDIRECT_GENERIC("throttle.max_downloads.global", "throttle.max_downloads.global._val");
+  CMD2_REDIRECT    ("throttle.max_uploads.div",      "throttle.max_uploads.div._val");
+  CMD2_REDIRECT    ("throttle.max_uploads.global",   "throttle.max_uploads.global._val");
+  CMD2_REDIRECT    ("throttle.max_downloads.div",    "throttle.max_downloads.div._val");
+  CMD2_REDIRECT    ("throttle.max_downloads.global", "throttle.max_downloads.global._val");
 
   CMD2_ANY_VALUE   ("throttle.max_uploads.div.set",      std::bind(&throttle_update, "throttle.max_uploads.div._val.set", std::placeholders::_2));
   CMD2_ANY_VALUE   ("throttle.max_uploads.global.set",   std::bind(&throttle_update, "throttle.max_uploads.global._val.set", std::placeholders::_2));
