@@ -1,39 +1,3 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <locale>
@@ -61,15 +25,15 @@ WindowFileList::WindowFileList(const ui::ElementFileList* element) :
 // Convert std::string to std::wstring of given width (in screen positions),
 // taking into account that some characters may be occupying two screen positions.
 std::wstring
-wstring_width(const std::string& i_str, int width) {
-  wchar_t result[width + 1];
-  size_t length = std::mbstowcs(result, i_str.c_str(), width);
+wstring_width(const std::string& i_str, [[maybe_unused]] int width) {
+  std::wstring result(width + 1, L' ');
+  size_t length = std::mbstowcs(result.data(), i_str.c_str(), width);
 
   // If not valid UTF-8 encoding, at least copy the printable characters.
   if (length == (size_t)-1) {
-    wchar_t* out = result;
+    wchar_t* out = result.data();
 
-    for (std::string::const_iterator itr = i_str.begin(); out != result + width && itr != i_str.end(); ++itr)
+    for (std::string::const_iterator itr = i_str.begin(); out != result.data() + width && itr != i_str.end(); ++itr)
       if (!std::isprint(*itr, std::locale::classic()))
         *out++ = '?';
       else
@@ -78,23 +42,23 @@ wstring_width(const std::string& i_str, int width) {
      *out = 0;
   }
 
-  int swidth = wcswidth(result, width);
+  int swidth = wcswidth(result.data(), width);
 
   // Limit to width if it's too wide already.
   if (swidth == -1 || swidth > width) {
     length = swidth = 0;
-    
-    while (result[length]) {
-      int next = ::wcwidth(result[length]);
+
+    while (result.data()[length]) {
+      int next = ::wcwidth(result.data()[length]);
 
       // Unprintable character?
       if (next == -1) {
-        result[length] = '?';
+        result.data()[length] = '?';
         next = 1;
       }
 
       if (swidth + next > width) {
-        result[length] = 0;
+        result.data()[length] = 0;
         break;
       }
 
@@ -105,18 +69,18 @@ wstring_width(const std::string& i_str, int width) {
 
   // Pad with spaces to given width.
   while (swidth < width && length <= (unsigned int)width) {
-    result[length++] = ' ';
+    result.data()[length++] = ' ';
     swidth++;
   }
 
-  result[length] = 0;
+  result.data()[length] = 0;
 
   return result;
 }
 
 void
 WindowFileList::redraw() {
-  m_slotSchedule(this, (cachedTime + rak::timer::from_seconds(10)).round_seconds());
+  schedule_update(10);
   m_canvas->erase();
 
   torrent::FileList* fl = m_element->download()->download()->file_list();
@@ -172,13 +136,13 @@ WindowFileList::redraw() {
 
     } else if (itr.is_entering()) {
       m_canvas->print(0, pos, "%*c %ls", 16 + itr.depth(), '\\',
-                      itr.depth() < (*itr)->path()->size() ? wstring_width((*itr)->path()->at(itr.depth()), filenameWidth - itr.depth() - 1).c_str() : L"UNKNOWN");
+                      itr.depth() < itr.file()->path()->size() ? wstring_width(itr.file()->path()->at(itr.depth()), filenameWidth - itr.depth() - 1).c_str() : L"UNKNOWN");
 
     } else if (itr.is_leaving()) {
       m_canvas->print(0, pos, "%*c %-*s", 16 + (itr.depth() - 1), '/', filenameWidth - (itr.depth() - 1), "");
 
     } else if (itr.is_file()) {
-      torrent::File* e = *itr;
+      torrent::File* e = itr.file();
 
       const char* priority;
 
@@ -203,7 +167,7 @@ WindowFileList::redraw() {
         m_canvas->print(8, pos, "%5.1f T", (double)val / (int64_t(1) << 40));
 
       m_canvas->print(15, pos, "%*c %ls", 1 + itr.depth(), '|',
-                      itr.depth() < (*itr)->path()->size() ? wstring_width((*itr)->path()->at(itr.depth()), filenameWidth - itr.depth() - 1).c_str() : L"UNKNOWN");
+                      itr.depth() < itr.file()->path()->size() ? wstring_width(itr.file()->path()->at(itr.depth()), filenameWidth - itr.depth() - 1).c_str() : L"UNKNOWN");
 
     } else {
       m_canvas->print(0, pos, "BORK BORK");
