@@ -10,6 +10,7 @@
 #include <torrent/torrent.h>
 #include <torrent/exceptions.h>
 #include <torrent/data/chunk_utils.h>
+#include <torrent/net/fd.h>
 #include <torrent/utils/chrono.h>
 #include <torrent/utils/log.h>
 #include <rak/error_number.h>
@@ -21,17 +22,19 @@
 #include "core/dht_manager.h"
 #include "core/download.h"
 #include "core/download_factory.h"
-#include "core/download_store.h"
 #include "core/manager.h"
 #include "display/canvas.h"
 #include "display/window.h"
 #include "display/manager.h"
 #include "input/bindings.h"
-#include "ui/root.h"
-
 #include "rpc/command_scheduler.h"
 #include "rpc/command_scheduler_item.h"
 #include "rpc/parse_commands.h"
+#include "scgi/thread_scgi.h"
+#include "session/download_storer.h"
+#include "session/thread_session.h"
+#include "session/session_manager.h"
+#include "ui/root.h"
 #include "utils/directory.h"
 
 #include "control.h"
@@ -40,8 +43,6 @@
 #include "signal_handler.h"
 #include "option_parser.h"
 
-#include "thread_worker.h"
-
 #define LT_LOG(log_fmt, ...)                                    \
   lt_log_print(torrent::LOG_SYSTEM, "system: " log_fmt, __VA_ARGS__);
 
@@ -112,7 +113,7 @@ initialize_rpc_slots() {
 
 void
 load_session_torrents() {
-  utils::Directory entries = control->core()->download_store()->get_formated_entries();
+  utils::Directory entries = session::DownloadStorer::get_formated_entries(session_thread::manager()->path());
 
   for (const auto& entry : entries) {
     // We don't really support session torrents that are links. These
@@ -214,8 +215,8 @@ main(int argc, char** argv) {
     torrent::initialize();
     torrent::set_main_thread_slots(std::bind(&client_perform));
 
-    worker_thread = new ThreadWorker();
-    worker_thread->init_thread();
+    scgi::ThreadScgi::create_thread();
+    session::ThreadSession::create_thread();
 
     // Initialize option handlers after libtorrent to ensure
     // torrent::ConnectionManager* are valid etc.
@@ -350,74 +351,76 @@ main(int argc, char** argv) {
     // Functions that might not get depracted as they are nice for
     // configuration files, and thus might do with just some
     // cleanup.
-    CMD2_REDIRECT("upload_rate",   "throttle.global_up.max_rate.set_kb");
-    CMD2_REDIRECT("download_rate", "throttle.global_down.max_rate.set_kb");
+    CMD2_REDIRECT("upload_rate",           "throttle.global_up.max_rate.set_kb");
+    CMD2_REDIRECT("download_rate",         "throttle.global_down.max_rate.set_kb");
 
-    CMD2_REDIRECT("ratio.enable",     "group.seeding.ratio.enable");
-    CMD2_REDIRECT("ratio.disable",    "group.seeding.ratio.disable");
-    CMD2_REDIRECT("ratio.min",        "group.seeding.ratio.min");
-    CMD2_REDIRECT("ratio.max",        "group.seeding.ratio.max");
-    CMD2_REDIRECT("ratio.upload",     "group.seeding.ratio.upload");
-    CMD2_REDIRECT("ratio.min.set",    "group.seeding.ratio.min.set");
-    CMD2_REDIRECT("ratio.max.set",    "group.seeding.ratio.max.set");
-    CMD2_REDIRECT("ratio.upload.set", "group.seeding.ratio.upload.set");
+    CMD2_REDIRECT("ratio.enable",          "group.seeding.ratio.enable");
+    CMD2_REDIRECT("ratio.disable",         "group.seeding.ratio.disable");
+    CMD2_REDIRECT("ratio.min",             "group.seeding.ratio.min");
+    CMD2_REDIRECT("ratio.max",             "group.seeding.ratio.max");
+    CMD2_REDIRECT("ratio.upload",          "group.seeding.ratio.upload");
+    CMD2_REDIRECT("ratio.min.set",         "group.seeding.ratio.min.set");
+    CMD2_REDIRECT("ratio.max.set",         "group.seeding.ratio.max.set");
+    CMD2_REDIRECT("ratio.upload.set",      "group.seeding.ratio.upload.set");
 
-    CMD2_REDIRECT("encryption",    "protocol.encryption.set");
-    CMD2_REDIRECT("encoding_list", "encoding.add");
+    CMD2_REDIRECT("encryption",            "protocol.encryption.set");
+    CMD2_REDIRECT("encoding_list",         "encoding.add");
 
-    CMD2_REDIRECT("connection_leech", "protocol.connection.leech.set");
-    CMD2_REDIRECT("connection_seed",  "protocol.connection.seed.set");
+    CMD2_REDIRECT("connection_leech",      "protocol.connection.leech.set");
+    CMD2_REDIRECT("connection_seed",       "protocol.connection.seed.set");
 
-    CMD2_REDIRECT("min_peers",      "throttle.min_peers.normal.set");
-    CMD2_REDIRECT("max_peers",      "throttle.max_peers.normal.set");
-    CMD2_REDIRECT("min_peers_seed", "throttle.min_peers.seed.set");
-    CMD2_REDIRECT("max_peers_seed", "throttle.max_peers.seed.set");
+    CMD2_REDIRECT("min_peers",             "throttle.min_peers.normal.set");
+    CMD2_REDIRECT("max_peers",             "throttle.max_peers.normal.set");
+    CMD2_REDIRECT("min_peers_seed",        "throttle.min_peers.seed.set");
+    CMD2_REDIRECT("max_peers_seed",        "throttle.max_peers.seed.set");
 
-    CMD2_REDIRECT("min_uploads",   "throttle.min_uploads.set");
-    CMD2_REDIRECT("max_uploads",   "throttle.max_uploads.set");
-    CMD2_REDIRECT("min_downloads", "throttle.min_downloads.set");
-    CMD2_REDIRECT("max_downloads", "throttle.max_downloads.set");
+    CMD2_REDIRECT("min_uploads",           "throttle.min_uploads.set");
+    CMD2_REDIRECT("max_uploads",           "throttle.max_uploads.set");
+    CMD2_REDIRECT("min_downloads",         "throttle.min_downloads.set");
+    CMD2_REDIRECT("max_downloads",         "throttle.max_downloads.set");
 
-    CMD2_REDIRECT("max_uploads_div",      "throttle.max_uploads.div.set");
-    CMD2_REDIRECT("max_uploads_global",   "throttle.max_uploads.global.set");
-    CMD2_REDIRECT("max_downloads_div",    "throttle.max_downloads.div.set");
-    CMD2_REDIRECT("max_downloads_global", "throttle.max_downloads.global.set");
+    CMD2_REDIRECT("max_uploads_div",       "throttle.max_uploads.div.set");
+    CMD2_REDIRECT("max_uploads_global",    "throttle.max_uploads.global.set");
+    CMD2_REDIRECT("max_downloads_div",     "throttle.max_downloads.div.set");
+    CMD2_REDIRECT("max_downloads_global",  "throttle.max_downloads.global.set");
 
-    CMD2_REDIRECT("max_memory_usage", "pieces.memory.max.set");
+    CMD2_REDIRECT("max_memory_usage",      "pieces.memory.max.set");
 
-    CMD2_REDIRECT("bind",       "network.bind_address.set");
-    CMD2_REDIRECT("ip",         "network.local_address.set");
-    CMD2_REDIRECT("port_range", "network.port_range.set");
+    CMD2_REDIRECT("bind",                  "network.bind_address.set");
+    CMD2_REDIRECT("ip",                    "network.local_address.set");
+    CMD2_REDIRECT("port_range",            "network.port_range.set");
 
-    CMD2_REDIRECT("dht",        "dht.mode.set");
+    CMD2_REDIRECT("dht",                   "dht.mode.set");
 
-    CMD2_REDIRECT("port_random", "network.port_random.set");
-    CMD2_REDIRECT("proxy_address", "network.proxy_address.set");
+    CMD2_REDIRECT("port_random",           "network.port_random.set");
+    CMD2_REDIRECT("proxy_address",         "network.proxy_address.set");
 
-    CMD2_REDIRECT("scgi_port", "network.scgi.open_port");
-    CMD2_REDIRECT("scgi_local", "network.scgi.open_local");
+    CMD2_REDIRECT("scgi_port",             "network.scgi.open_port");
+    CMD2_REDIRECT("scgi_local",            "network.scgi.open_local");
 
-    CMD2_REDIRECT("directory", "directory.default.set");
-    CMD2_REDIRECT("session",   "session.path.set");
+    CMD2_REDIRECT("directory",             "directory.default.set");
+    CMD2_REDIRECT("session",               "session.path.set");
 
-    CMD2_REDIRECT("check_hash", "pieces.hash.on_completion.set");
+    CMD2_REDIRECT("check_hash",            "pieces.hash.on_completion.set");
 
-    CMD2_REDIRECT("key_layout", "keys.layout.set");
+    CMD2_REDIRECT("key_layout",            "keys.layout.set");
 
-    CMD2_REDIRECT("to_gm_time", "convert.gm_time");
-    CMD2_REDIRECT("to_gm_date", "convert.gm_date");
-    CMD2_REDIRECT("to_time", "convert.time");
-    CMD2_REDIRECT("to_date", "convert.date");
-    CMD2_REDIRECT("to_elapsed_time", "convert.elapsed_time");
-    CMD2_REDIRECT("to_kb", "convert.kb");
-    CMD2_REDIRECT("to_mb", "convert.mb");
-    CMD2_REDIRECT("to_xb", "convert.xb");
-    CMD2_REDIRECT("to_throttle", "convert.throttle");
+    CMD2_REDIRECT("to_gm_time",            "convert.gm_time");
+    CMD2_REDIRECT("to_gm_date",            "convert.gm_date");
+    CMD2_REDIRECT("to_time",               "convert.time");
+    CMD2_REDIRECT("to_date",               "convert.date");
+    CMD2_REDIRECT("to_elapsed_time",       "convert.elapsed_time");
+    CMD2_REDIRECT("to_kb",                 "convert.kb");
+    CMD2_REDIRECT("to_mb",                 "convert.mb");
+    CMD2_REDIRECT("to_xb",                 "convert.xb");
+    CMD2_REDIRECT("to_throttle",           "convert.throttle");
 
-    CMD2_REDIRECT("torrent_list_layout", "ui.torrent_list.layout.set");
+    CMD2_REDIRECT("torrent_list_layout",   "ui.torrent_list.layout.set");
 
     // Deprecate:
 
+    CMD2_VAR_STRING("dht.throttle.name",   "deprecated");
+
     CMD2_REDIRECT("network.http.max_open",     "network.http.max_total_connections");
     CMD2_REDIRECT("network.http.max_open.set", "network.http.max_total_connections.set");
 
@@ -443,6 +446,19 @@ main(int argc, char** argv) {
     // if (rpc::call_command_value("method.use_deprecated") == 1) {
     // }
 
+    {
+      auto fd = torrent::fd_open_family(torrent::fd_flag_stream, AF_INET6);
+
+      if (fd == -1) {
+        if (errno == EAFNOSUPPORT) {
+          lt_log_print(torrent::LOG_WARN, "disabling ipv6 support, not available on system");
+          rpc::call_command_set_value("network.block.ipv6.set", true);
+        }
+      } else {
+        torrent::fd_close(fd);
+      }
+    }
+
     int firstArg = parse_options(argc, argv);
 
     if (OptionParser::has_flag('n', argc, argv)) {
@@ -482,8 +498,6 @@ main(int argc, char** argv) {
     control->display()->adjust_layout();
     control->display()->receive_update();
 
-    worker_thread->start_thread();
-
     rpc::commands.call_catch("event.system.startup_done", rpc::make_target(), "startup_done", "System startup_done event action failed: ");
 
     torrent::utils::Thread::self()->event_loop();
@@ -515,10 +529,13 @@ main(int argc, char** argv) {
     return -1;
   }
 
-  torrent::log_cleanup();
-
   delete control;
-  delete worker_thread;
+  control = nullptr;
+
+  scgi::ThreadScgi::destroy_thread();
+  session::ThreadSession::destroy_thread();
+
+  torrent::log_cleanup();
 
   return 0;
 }
