@@ -190,7 +190,7 @@ parse_object(const char* first, const char* last, torrent::Object* dest, bool (*
     }
 
     if (depth > 3)
-      throw torrent::input_error("Max 3 parantheses per object allowed.");
+      throw torrent::input_error("Max 3 parentheses per object allowed.");
 
     *dest = torrent::Object::create_dict_key();
     dest->set_flags(torrent::Object::flag_function << (depth - 1));
@@ -214,7 +214,7 @@ parse_object(const char* first, const char* last, torrent::Object* dest, bool (*
     }
 
     if (depth != 0)
-      throw torrent::input_error("Parantheses mismatch.");
+      throw torrent::input_error("Parentheses mismatch.");
 
     return first;
 
@@ -405,12 +405,12 @@ convert_to_value_nothrow(const torrent::Object& src, int64_t* value, int base, i
   case torrent::Object::TYPE_RAW_STRING: {
     const torrent::raw_string& str = src.as_raw_string();
 
-    char buffer[str.size() + 1];
-    std::memcpy(buffer, str.data(), str.size());
+    auto buffer = std::make_unique<char[]>(str.size() + 1);
+    std::memcpy(buffer.get(), str.data(), str.size());
     buffer[str.size()] = '\0';
 
-    return parse_skip_wspace(parse_value(buffer, value, base, unit), buffer + str.size())
-      == buffer + str.size();
+    return parse_skip_wspace(parse_value(buffer.get(), value, base, unit), buffer.get() + str.size())
+      == buffer.get() + str.size();
   }
   case torrent::Object::TYPE_NONE:
     *value = 0;
@@ -453,8 +453,8 @@ print_object(char* first, char* last, const torrent::Object* src, int flags) {
     if (first != last)
       *first = '\0';
 
-    for (torrent::Object::list_const_iterator itr = src->as_list().begin(), itrEnd = src->as_list().end(); itr != itrEnd; itr++) {
-      first = print_object(first, last, &*itr, flags);
+    for (const auto& itr : src->as_list()) {
+      first = print_object(first, last, &itr, flags);
 
       // Don't expand tilde after the first element in the list.
       flags &= ~print_expand_tilde;
@@ -495,8 +495,8 @@ print_object_std(std::string* dest, const torrent::Object* src, int flags) {
     return;
   }
   case torrent::Object::TYPE_LIST:
-    for (torrent::Object::list_const_iterator itr = src->as_list().begin(), itrEnd = src->as_list().end(); itr != itrEnd; itr++) {
-      print_object_std(dest, &*itr, flags);
+    for (const auto& itr : src->as_list()) {
+      print_object_std(dest, &itr, flags);
 
       // Don't expand tilde after the first element in the list.
       flags &= ~print_expand_tilde;
