@@ -8,9 +8,9 @@
 #include <cctype>
 #include <string>
 #include <stdlib.h>
-#include <rak/string_manip.h>
 #include <torrent/object.h>
 #include <torrent/exceptions.h>
+#include <torrent/utils/string_manip.h>
 #include <xmlrpc-c/server.h>
 
 #include "rpc_manager.h"
@@ -282,24 +282,20 @@ object_to_xmlrpc(xmlrpc_env* env, const torrent::Object& object) {
     // The versions that support I8 do implicit utf-8 validation.
     xmlrpc_value* result = xmlrpc_string_new(env, object.as_string().c_str());
 #else
+    xmlrpc_value* result{};
+
     // In older versions, xmlrpc-c doesn't validate the utf-8 encoding itself.
     xmlrpc_validate_utf8(env, object.as_string().c_str(), object.as_string().length());
 
-    xmlrpc_value* result = env->fault_occurred ? NULL : xmlrpc_string_new(env, object.as_string().c_str());
+    if (!env->fault_occurred)
+      result = xmlrpc_string_new(env, object.as_string().c_str());
 #endif
 
     if (env->fault_occurred) {
       xmlrpc_env_clean(env);
       xmlrpc_env_init(env);
 
-      const std::string& str = object.as_string();
-      char buffer[str.size() + 1];
-      char* dst = buffer;
-      for (char itr : str)
-        *dst++ = ((itr < 0x20 && itr != '\r' && itr != '\n' && itr != '\t') || (itr & 0x80)) ? '?' : itr;
-      *dst = 0;
-
-      result = xmlrpc_string_new(env, buffer);
+      return xmlrpc_string_new(env, torrent::utils::string_with_escape_codes(object.as_string()).c_str());
     }
 
     return result;
@@ -361,10 +357,12 @@ object_to_xmlrpc(xmlrpc_env* env, const torrent::Object& object) {
 
 xmlrpc_value*
 xmlrpc_call_command(xmlrpc_env* env, xmlrpc_value* args, void* voidServerInfo) {
-  CommandMap::iterator itr = commands.find((const char*)voidServerInfo);
+  auto server_info = static_cast<const char*>(voidServerInfo);
+
+  CommandMap::iterator itr = commands.find(server_info);
 
   if (itr == commands.end()) {
-    xmlrpc_env_set_fault(env, XMLRPC_PARSE_ERROR, ("Command \"" + std::string((const char*)voidServerInfo) + "\" does not exist.").c_str());
+    xmlrpc_env_set_fault(env, XMLRPC_PARSE_ERROR, ("Command \"" + std::string(server_info) + "\" does not exist.").c_str());
     return NULL;
   }
 
@@ -397,6 +395,11 @@ xmlrpc_call_command(xmlrpc_env* env, xmlrpc_value* args, void* voidServerInfo) {
   }
 }
 
+bool
+XmlRpc::is_valid() const {
+  return m_env != NULL;
+}
+
 void
 XmlRpc::initialize() {
 #ifndef XMLRPC_HAVE_I8
@@ -421,34 +424,42 @@ XmlRpc::cleanup() {
 
 bool
 XmlRpc::process(const char* inBuffer, uint32_t length, slot_write slotWrite) {
-  xmlrpc_env localEnv;
-  xmlrpc_env_init(&localEnv);
+  xmlrpc_env local_env;
+  xmlrpc_env_init(&local_env);
 
-  xmlrpc_mem_block* memblock = xmlrpc_registry_process_call(&localEnv, (xmlrpc_registry*)m_registry, NULL, inBuffer, length);
+  xmlrpc_mem_block* memblock = xmlrpc_registry_process_call(&local_env, (xmlrpc_registry*)m_registry, NULL, inBuffer, length);
 
-  if (localEnv.fault_occurred && localEnv.fault_code == XMLRPC_INTERNAL_ERROR)
+  if (local_env.fault_occurred && local_env.fault_code == XMLRPC_INTERNAL_ERROR)
     throw torrent::internal_error("Internal error in XMLRPC.");
 
   bool result = slotWrite((const char*)xmlrpc_mem_block_contents(memblock),
                           xmlrpc_mem_block_size(memblock));
 
   xmlrpc_mem_block_free(memblock);
-  xmlrpc_env_clean(&localEnv);
+  xmlrpc_env_clean(&local_env);
   return result;
 }
 
 void
 XmlRpc::insert_command(const char* name, const char* parm, const char* doc) {
-  xmlrpc_env localEnv;
-  xmlrpc_env_init(&localEnv);
+  xmlrpc_env local_env;
+  xmlrpc_env_init(&local_env);
 
-  xmlrpc_registry_add_method_w_doc(&localEnv, (xmlrpc_registry*)m_registry, NULL, name,
-                                   &xmlrpc_call_command, const_cast<char*>(name), parm, doc);
+  auto stored_name = store_command_name(name);
 
-  if (localEnv.fault_occurred)
+  xmlrpc_registry_add_method_w_doc(&local_env,
+                                   (xmlrpc_registry*)m_registry,
+                                   nullptr,
+                                   stored_name,
+                                   &xmlrpc_call_command,
+                                   (void*)stored_name,
+                                   parm,
+                                   doc);
+
+  if (local_env.fault_occurred)
     throw torrent::internal_error("Fault occured while inserting xmlrpc call.");
 
-  xmlrpc_env_clean(&localEnv);
+  xmlrpc_env_clean(&local_env);
 }
 
 void
@@ -456,8 +467,8 @@ XmlRpc::set_dialect(int dialect) {
   if (!is_valid())
     throw torrent::input_error("Cannot select XMLRPC dialect before it is initialized.");
 
-  xmlrpc_env localEnv;
-  xmlrpc_env_init(&localEnv);
+  xmlrpc_env local_env;
+  xmlrpc_env_init(&local_env);
 
   switch (dialect) {
   case dialect_generic:
@@ -465,25 +476,25 @@ XmlRpc::set_dialect(int dialect) {
 
 #ifdef XMLRPC_HAVE_I8
   case dialect_i8:
-    xmlrpc_registry_set_dialect(&localEnv, (xmlrpc_registry*)m_registry, xmlrpc_dialect_i8);
+    xmlrpc_registry_set_dialect(&local_env, (xmlrpc_registry*)m_registry, xmlrpc_dialect_i8);
     break;
 
   case dialect_apache:
-    xmlrpc_registry_set_dialect(&localEnv, (xmlrpc_registry*)m_registry, xmlrpc_dialect_apache);
+    xmlrpc_registry_set_dialect(&local_env, (xmlrpc_registry*)m_registry, xmlrpc_dialect_apache);
     break;
 #endif
 
   default:
-    xmlrpc_env_clean(&localEnv);
+    xmlrpc_env_clean(&local_env);
     throw torrent::input_error("Unsupported XMLRPC dialect selected.");
   }
 
-  if (localEnv.fault_occurred) {
-    xmlrpc_env_clean(&localEnv);
+  if (local_env.fault_occurred) {
+    xmlrpc_env_clean(&local_env);
     throw torrent::input_error("Unsupported XMLRPC dialect selected.");
   }
 
-  xmlrpc_env_clean(&localEnv);
+  xmlrpc_env_clean(&local_env);
   m_dialect = dialect;
 }
 
@@ -500,9 +511,6 @@ XmlRpc::set_size_limit(uint64_t size) {
   xmlrpc_limit_set(XMLRPC_XML_SIZE_LIMIT_ID, size);
 }
 
-bool
-XmlRpc::is_valid() const { return m_env != NULL; }
-
 } // namespace rpc
 
 #endif
