@@ -48,6 +48,7 @@
 #include "control.h"
 #include "element_file_list.h"
 #include "element_text.h"
+#include "root.h"
 
 namespace ui {
 
@@ -55,8 +56,8 @@ ElementFileList::ElementFileList(core::Download* d) :
     m_download(d),
     m_selected(iterator(d->download()->file_list()->begin())) {
 
-  m_bindings[KEY_LEFT]  = m_bindings['B' - '@'] = std::bind(&slot_type::operator(), &m_slot_exit);
-  m_bindings[KEY_RIGHT] = m_bindings['F' - '@'] = std::bind(&ElementFileList::receive_select, this);
+  m_bindings[KEY_LEFT]  = m_bindings[control->ui()->navigation_key(RT_KEY_LEFT)]  = std::bind(&slot_type::operator(), &m_slot_exit);
+  m_bindings[KEY_RIGHT] = m_bindings[control->ui()->navigation_key(RT_KEY_RIGHT)] = std::bind(&ElementFileList::receive_select, this);
 
   m_bindings[' '] = std::bind(&ElementFileList::receive_priority, this);
   m_bindings['*'] = std::bind(&ElementFileList::receive_change_all, this);
@@ -64,8 +65,8 @@ ElementFileList::ElementFileList(core::Download* d) :
   m_bindings[KEY_NPAGE] = std::bind(&ElementFileList::receive_pagenext, this);
   m_bindings[KEY_PPAGE] = std::bind(&ElementFileList::receive_pageprev, this);
 
-  m_bindings[KEY_DOWN] = m_bindings['N' - '@'] = std::bind(&ElementFileList::receive_next, this);
-  m_bindings[KEY_UP]   = m_bindings['P' - '@'] = std::bind(&ElementFileList::receive_prev, this);
+  m_bindings[KEY_DOWN]  = m_bindings[control->ui()->navigation_key(RT_KEY_DOWN)]  = std::bind(&ElementFileList::receive_next, this);
+  m_bindings[KEY_UP]    = m_bindings[control->ui()->navigation_key(RT_KEY_UP)]    = std::bind(&ElementFileList::receive_prev, this);
 }
 
 inline ElementText*
@@ -276,14 +277,13 @@ ElementFileList::receive_priority() {
 
 void
 ElementFileList::receive_change_all() {
-  if (m_window == NULL)
+  if (m_window == nullptr)
     return;
 
-  torrent::FileList* fl = m_download->download()->file_list();
   auto priority = torrent::priority_enum((m_selected.file()->priority() + 2) % 3);
 
-  for (torrent::FileList::iterator itr = fl->begin(), last = fl->end(); itr != last; ++itr)
-    (*itr)->set_priority(priority);
+  for (const auto& file : *m_download->download()->file_list())
+    file->set_priority(priority);
 
   m_download->download()->update_priorities();
   update_itr();
