@@ -1,5 +1,7 @@
 #include "config.h"
 
+#include "ui/root.h"
+
 #include <fstream>
 #include <stdexcept>
 #include <string.h>
@@ -9,6 +11,8 @@
 #include <torrent/download/resource_manager.h>
 #include <torrent/utils/log.h>
 
+#include "control.h"
+#include "core/download_list.h"
 #include "core/manager.h"
 #include "display/frame.h"
 #include "display/window_http_queue.h"
@@ -18,12 +22,7 @@
 #include "input/manager.h"
 #include "input/text_input.h"
 #include "rpc/parse_commands.h"
-
-#include "control.h"
-#include "download_list.h"
-#include "core/download_store.h"
-
-#include "root.h"
+#include "session/session_manager.h"
 
 namespace ui {
 
@@ -83,13 +82,13 @@ Root::init(Control* c) {
 
   m_downloadList    = std::make_unique<DownloadList>();
 
-  display::Frame* rootFrame = m_control->display()->root_frame();
+  auto root_frame = m_control->display()->root_frame();
 
-  rootFrame->initialize_row(5);
-  rootFrame->frame(0)->initialize_window(m_windowTitle.get());
-  rootFrame->frame(2)->initialize_window(m_windowHttpQueue.get());
-  rootFrame->frame(3)->initialize_window(m_windowInput.get());
-  rootFrame->frame(4)->initialize_window(m_windowStatusbar.get());
+  root_frame->initialize_row(5);
+  root_frame->frame(0)->initialize_window(m_windowTitle.get());
+  root_frame->frame(2)->initialize_window(m_windowHttpQueue.get());
+  root_frame->frame(3)->initialize_window(m_windowInput.get());
+  root_frame->frame(4)->initialize_window(m_windowStatusbar.get());
 
   m_windowTitle->set_active(true);
   m_windowStatusbar->set_active(true);
@@ -97,7 +96,7 @@ Root::init(Control* c) {
 
   setup_keys();
 
-  m_downloadList->activate(rootFrame->frame(1));
+  m_downloadList->activate(root_frame->frame(1));
 }
 
 void
@@ -111,7 +110,14 @@ Root::cleanup() {
   m_control->display()->root_frame()->clear();
   m_control->input()->erase(&m_bindings);
 
-  m_control = NULL;
+  // Destroy windows in reverse order of creation.
+  m_windowStatusbar = nullptr;
+  m_windowInput     = nullptr;
+  m_windowHttpQueue = nullptr;
+  m_windowTitle     = nullptr;
+  m_downloadList    = nullptr;
+
+  m_control = nullptr;
 }
 
 const char*
@@ -371,13 +377,13 @@ Root::set_input_history_size(int size) {
 
 void
 Root::load_input_history() {
-  if (m_control == nullptr || !m_control->core()->download_store()->is_enabled()) {
+  if (m_control == nullptr || !session_thread::manager()->is_used()) {
     lt_log_print(torrent::LOG_DEBUG, "ignoring input history file");
     return;
   }
 
-  std::string history_filename = m_control->core()->download_store()->path() + "rtorrent.input_history";
-  std::fstream history_file(history_filename.c_str(), std::ios::in);
+  auto history_filename = session_thread::manager()->path() + "rtorrent.input_history";
+  auto history_file     = std::fstream(history_filename.c_str(), std::ios::in);
 
   if (history_file.is_open()) {
     // Create a temp object of the content since size of history categories can be smaller than this.
@@ -439,12 +445,12 @@ Root::load_input_history() {
 
 void
 Root::save_input_history() {
-  if (m_control == nullptr || !m_control->core()->download_store()->is_enabled())
+  if (m_control == nullptr || !session_thread::manager()->is_used())
     return;
 
-  std::string history_filename = m_control->core()->download_store()->path() + "rtorrent.input_history";
-  std::string history_filename_tmp = history_filename + ".new";
-  std::fstream history_file(history_filename_tmp.c_str(), std::ios::out | std::ios::trunc);
+  auto history_filename     = session_thread::manager()->path() + "rtorrent.input_history";
+  auto history_filename_tmp = history_filename + ".new";
+  auto history_file         = std::fstream(history_filename_tmp.c_str(), std::ios::out | std::ios::trunc);
 
   if (!history_file.is_open()) {
     lt_log_print(torrent::LOG_DEBUG, "could not open input history file for writing (path:%s)", history_filename.c_str());
@@ -496,7 +502,7 @@ Root::set_keymap_style(const std::string& style) {
   m_keymap_style = style;
 }
 
-const int
+int
 Root::navigation_key(NavigationKeymap key) {
   return m_keymap[key];
 }
